@@ -83,7 +83,7 @@ class Parser():
 
             # 조종
             #                           1        2      3       4     5          6
-            # python -m e_drone_nightly control [roll] [pitch] [yaw] [throttle] [time(msec)]
+            # python -m e_drone_nightly control [roll] [pitch] [yaw] [throttle] [time(ms)]
             # 지정한 시간이 종료되면 입력값을 모두 0으로 변경하고 멈춤
             # >python -m e_drone_nightly control 40 0 3
             elif    ((self.count == 6) and 
@@ -103,7 +103,7 @@ class Parser():
 
             # 버저
             #                   1       2    3
-            # python -m e_drone buzzer [hz] [time(msec)]
+            # python -m e_drone buzzer [hz] [time(ms)]
             # >python -m e_drone buzzer 400 2000
             elif    ((self.count == 3) and 
                     (self.arguments[0] == "buzzer")):
@@ -111,6 +111,17 @@ class Parser():
                 self.buzzer(DeviceType.Controller, int(self.arguments[1]), int(self.arguments[2]))
                 return
 
+            # 진동
+            #                   1         2          3           4
+            # python -m e_drone vibrator [on(ms)] [off(ms)] [total(ms)]
+            # >python -m e_drone vibrator 500 500 2000
+            elif    ((self.count == 4) and 
+                    (self.arguments[0] == "vibrator")):
+                print (Fore.WHITE + "Vibrator: on " + Fore.YELLOW + "{0}".format(int(self.arguments[1])) + Fore.WHITE + "ms, off " + Fore.CYAN + "{0}".format(int(self.arguments[2])) + Fore.WHITE + "ms, total " + Fore.CYAN + "{0}".format(int(self.arguments[3])) + Fore.WHITE + "ms" + Style.RESET_ALL)
+                self.vibrator(DeviceType.Controller, int(self.arguments[1]), int(self.arguments[2]), int(self.arguments[3]))
+                return
+
+
             # >python -m e_drone light body flicker 100 50 50 10
             # >python -m e_drone light body flickerdouble 100 50 50 10
             # >python -m e_drone light body dimming 3 50 50 10
@@ -318,6 +329,35 @@ class Parser():
         sleep(time / 1000)
 
 
+    def vibrator(self, target, on, off, total):
+
+        drone = Drone(True, True, True, True, True)
+        #drone = Drone()
+        if drone.open() == False:
+            print(Fore.RED + "* Error : Unable to open serial port." + Style.RESET_ALL)
+            sys.exit(1)
+        
+        if ( (not isinstance(on, int)) or (not isinstance(off, int)) or (not isinstance(total, int)) ):
+            return None
+
+        header = Header()
+        
+        header.dataType = DataType.Vibrator
+        header.length   = Vibrator.getSize()
+        header.from_    = DeviceType.Base
+        header.to_      = target
+        
+        data = Vibrator()
+
+        data.mode       = VibratorMode.Instantally
+        data.on         = on
+        data.off        = off
+        data.total      = total
+
+        drone.transfer(header, data)
+        sleep(total / 1000)
+
+
     def help(self):
 
         print(Fore.YELLOW + "* Command List " + Style.RESET_ALL)
@@ -337,7 +377,7 @@ class Parser():
 
         print("")
         print(Fore.CYAN + "  - Control - Accel Wheel" + Style.RESET_ALL)
-        print(Fore.GREEN + "   > " + Fore.WHITE + "python -m e_drone " + Fore.CYAN + "control " + Fore.WHITE + "[" + Fore.YELLOW + "accel" + Fore.WHITE + "] [" + Fore.GREEN + "wheel" + Fore.WHITE + "] [" + Fore.YELLOW + "time(msec)" + Fore.WHITE + "]" + Style.RESET_ALL)
+        print(Fore.GREEN + "   > " + Fore.WHITE + "python -m e_drone " + Fore.CYAN + "control " + Fore.WHITE + "[" + Fore.YELLOW + "accel" + Fore.WHITE + "] [" + Fore.GREEN + "wheel" + Fore.WHITE + "] [" + Fore.YELLOW + "time(ms)" + Fore.WHITE + "]" + Style.RESET_ALL)
         print(Fore.GREEN + "   > " + Fore.WHITE + "python -m e_drone " + Fore.CYAN + "control " + Fore.YELLOW + "40 0 3000" + Style.RESET_ALL)
 
         print("")
@@ -352,9 +392,14 @@ class Parser():
 
         print("")
         print(Fore.CYAN + "  - Buzzer" + Style.RESET_ALL)
-        print(Fore.GREEN + "   > " + Fore.WHITE + "python -m e_drone " + Fore.CYAN + "buzzer " + Fore.WHITE + "[" + Fore.YELLOW + "hz" + Fore.WHITE + "] [" + Fore.GREEN + "time(msec)" + Fore.WHITE + "]" + Style.RESET_ALL)
+        print(Fore.GREEN + "   > " + Fore.WHITE + "python -m e_drone " + Fore.CYAN + "buzzer " + Fore.WHITE + "[" + Fore.YELLOW + "hz" + Fore.WHITE + "] [" + Fore.GREEN + "time(ms)" + Fore.WHITE + "]" + Style.RESET_ALL)
         print(Fore.GREEN + "   > " + Fore.WHITE + "python -m e_drone " + Fore.CYAN + "buzzer " + Fore.YELLOW + "400 2000" + Style.RESET_ALL)
 
+        print("")
+        print(Fore.CYAN + "  - Vibrator" + Style.RESET_ALL)
+        print(Fore.GREEN + "   > " + Fore.WHITE + "python -m e_drone " + Fore.CYAN + "vibrator " + Fore.WHITE + "[" + Fore.YELLOW + "on(ms)" + Fore.WHITE + "] [" + Fore.GREEN + "off(ms)" + Fore.WHITE + "] [" + Fore.GREEN + "total(ms)" + Fore.WHITE + "]" + Style.RESET_ALL)
+        print(Fore.GREEN + "   > " + Fore.WHITE + "python -m e_drone " + Fore.CYAN + "vibrator " + Fore.YELLOW + "500 500 2000" + Style.RESET_ALL)
+
         print("")
         print(Fore.CYAN + "  - Light single" + Style.RESET_ALL)
         print(Fore.GREEN + "   > " + Fore.WHITE + "python -m e_drone " + Fore.CYAN + "light " + Fore.WHITE + "[" + Fore.YELLOW + "part" + Fore.WHITE + "] [" + Fore.GREEN + "mode" + Fore.WHITE + "] [" + Fore.YELLOW + "interval" + Fore.WHITE + "]" + Style.RESET_ALL)
